CalculationOptions class

Configuration options for distance calculations.

Wraps algorithm-specific options (currently only lcsOptions for the LCS algorithm). Use CalculationOptions.defaultOne to obtain a sensible default instance.

Constructors

CalculationOptions({required LcsOptions? lcsOptions})
Creates a CalculationOptions with the given lcsOptions.

Properties

hashCode int
The hash code for this object.
no setterinherited
lcsOptions LcsOptions?
Options specific to the LCS (Longest Common Subsequence) algorithm.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

defaultOne() CalculationOptions
Returns a default CalculationOptions with LcsOptions at their defaults.