lcsOptions property
Options specific to the LCS (Longest Common Subsequence) algorithm.
May be null for distance calculators that do not use LCS.
Implementation
final LcsOptions? lcsOptions;
Options specific to the LCS (Longest Common Subsequence) algorithm.
May be null for distance calculators that do not use LCS.
final LcsOptions? lcsOptions;