LcsOptions class

Options specific to the LCS (Longest Common Subsequence) algorithm.

Constructors

LcsOptions()

Properties

containsOnlyLongestSubSequences bool
When true (the default), only sub-sequences of the maximum found length are included in the result. When false, all found sub-sequences are returned regardless of length.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited