DistanceInfo class
Holds the result of a distance computation between input strings.
Returned by IDistanceCalculator.getDistanceInfo.
Constructors
Properties
- distance ↔ double
-
The computed distance value. A value of
-1indicates no computation has been performed.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- lcsInfo ↔ LcsInfo?
-
Optional LCS-specific information when the distance was computed using
the Longest Common Subsequence algorithm.
getter/setter pair
-
originalInputs
↔ List<
String> ? -
The original input strings that were compared.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited