DataLengthPrefix class
A data-length prefix with a name, symbol, and value.
Used by BinarySizeConventionStandard to describe the prefixes for each level of the size scale (e.g. "kibi", "Ki", 1024).
Constructors
- DataLengthPrefix({required String name, required String symbol, required BigInt value})
-
Creates a DataLengthPrefix with the given
name,symbol, andvalue.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The full name of the prefix (e.g. "kibi", "mebi", "giga").
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- symbol → String
-
The abbreviated symbol of the prefix (e.g. "Ki", "Mi", "G").
final
- value → BigInt
-
The numeric value this prefix represents (e.g. 1024 for kibi, 1000 for kilo).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited